#!/bin/sh

# ZIGA $Id: t0015a.sh,v 1.3 1998/09/25 21:14:31 software Exp $

work=${TMPDIR:-/tmp}/$$

here=`pwd`
if test $? -ne 0 ; then exit 2 ; fi

prog=${PROG:-cons}
progstr="$prog [recursive #include <...>]"
case $prog in
/* ) ;;
* ) prog=$here/$prog ;;
esac

cleanup()
{
	if test X$PRESERVE = X -a X$1 = X ; then
		cd $here
		find $work -type d -user $USER -exec chmod u+w {} \;
		rm -rf $work
	else
		echo Preserving work directory $work
	fi
}

no_result()
{
	set +x
	echo NO RESULT for test of $progstr 1>&2
	cleanup $PRESERVE_NO_RESULT
	exit 2
}
fail()
{
	set +x
	if test "$1" ; then teststr=" #$1" ; fi
	if test "$2" ; then
		echo FAILED test$teststr of $progstr, input: 1>&2
		cat $2 1>&2
	fi
	echo FAILED test of $progstr 1>&2
	cleanup $PRESERVE_FAIL
	exit 1
}
pass()
{
	set +x
	echo PASSED 1>&2
	cleanup $PRESERVE_PASS
	exit 0
}
trap "no_result" 1 2 3 15

#
# make the work directory
#
mkdir $work
if test $? -ne 0 ; then exit 2 ; fi
cd $work
if test $? -ne 0 ; then exit 2 ; fi

mkdir include
if test $? -ne 0 ; then no_result ; fi
mkdir zark
if test $? -ne 0 ; then no_result ; fi

#
cat <<'_EOF_' >Construct
$env = new cons (
	CPPPATH => '.',
);
Program $env 'foo', 'foo.c';
_EOF_
if test $? -ne 0 ; then no_result ; fi
cat <<'_EOF_' >foo.c
#include <include/foo.h>
main()
{
	printf(STRING);
	exit (0);
}
_EOF_
if test $? -ne 0 ; then no_result ; fi

cat <<'_EOF_' >include/foo.h
#include <include/bar.h>
_EOF_
if test $? -ne 0 ; then no_result ; fi

cat <<'_EOF_' >include/bar.h
#define	STRING	"This is the first include/bar.h file.\n"
_EOF_
if test $? -ne 0 ; then no_result ; fi
$prog . > cons.1.out 2>&1
if test $? -ne 0 ; then fail ; fi
./foo > foo.out
if test $? -ne 0 ; then fail ; fi
diff - foo.out <<'_EOF_'
This is the first include/bar.h file.
_EOF_
if test $? -ne 0 ; then fail ; fi

cat <<'_EOF_' >include/bar.h
#define	STRING	"This is the include/bar.h file the second.\n"
_EOF_
if test $? -ne 0 ; then no_result ; fi
$prog . > cons.2.out 2>&1
if test $? -ne 0 ; then fail ; fi
./foo > foo.out
if test $? -ne 0 ; then fail ; fi
diff - foo.out <<'_EOF_'
This is the include/bar.h file the second.
_EOF_
if test $? -ne 0 ; then fail ; fi

#
pass
