#!/bin/sh

# ZIGA $Id: t0021a.sh,v 1.3 1998/09/25 21:14:31 software Exp $

work=${TMPDIR:-/tmp}/$$

here=`pwd`
if test $? -ne 0 ; then exit 2 ; fi

prog=${PROG:-cons}
progstr="$prog [Default]"
case $prog in
/* ) ;;
* ) prog=$here/$prog ;;
esac

cleanup()
{
	if test X$PRESERVE = X -a X$1 = X ; then
		cd $here
		find $work -type d -user $USER -exec chmod u+w {} \;
		rm -rf $work
	else
		echo Preserving work directory $work
	fi
}

no_result()
{
	set +x
	echo NO RESULT for test of $progstr 1>&2
	cleanup $PRESERVE_NO_RESULT
	exit 2
}
fail()
{
	set +x
	if test "$1" ; then teststr=" #$1" ; fi
	if test "$2" ; then
		echo FAILED test$teststr of $progstr, input: 1>&2
		cat $2 1>&2
	fi
	echo FAILED test of $progstr 1>&2
	cleanup $PRESERVE_FAIL
	exit 1
}
pass()
{
	set +x
	echo PASSED 1>&2
	cleanup $PRESERVE_PASS
	exit 0
}
trap "no_result" 1 2 3 15

#
# make the work directory
#
mkdir $work
if test $? -ne 0 ; then exit 2 ; fi
cd $work
if test $? -ne 0 ; then exit 2 ; fi

#
cat <<'_EOF_' >Construct
$env = new cons;
Program $env 'aaa', 'aaa.c';
Program $env 'bbb', 'bbb.c';
Program $env 'ccc', 'ccc.c';
Default qw(
	bbb
);
_EOF_
if test $? -ne 0 ; then no_result ; fi
cat <<'_EOF_' >aaa.c
main()
{
	printf("This is the aaa.c file.\n");
	exit (0);
}
_EOF_
if test $? -ne 0 ; then no_result ; fi
cat <<'_EOF_' >bbb.c
main()
{
	printf("This is the bbb.c file.\n");
	exit (0);
}
_EOF_
if test $? -ne 0 ; then no_result ; fi
cat <<'_EOF_' >ccc.c
main()
{
	printf("This is the ccc.c file.\n");
	exit (0);
}
_EOF_
if test $? -ne 0 ; then no_result ; fi

$prog > cons.1.out 2>&1
if test $? -ne 0 ; then fail ; fi
if test -x aaa ; then fail ; fi
if test -x ccc ; then fail ; fi
./bbb > bbb.out
if test $? -ne 0 ; then fail ; fi
diff - bbb.out <<'_EOF_'
This is the bbb.c file.
_EOF_
if test $? -ne 0 ; then fail ; fi

$prog . > cons.2.out 2>&1
./aaa > aaa.out
if test $? -ne 0 ; then fail ; fi
diff - aaa.out <<'_EOF_'
This is the aaa.c file.
_EOF_
if test $? -ne 0 ; then fail ; fi
./ccc > ccc.out
if test $? -ne 0 ; then fail ; fi
diff - ccc.out <<'_EOF_'
This is the ccc.c file.
_EOF_
if test $? -ne 0 ; then fail ; fi

#
pass
