#!/bin/sh

# ZIGA $Id: t0027a.sh,v 1.4 1998/09/25 21:54:53 software Exp $

work=${TMPDIR:-/tmp}/$$

here=`pwd`
if test $? -ne 0 ; then exit 2 ; fi

prog=${PROG:-cons}
progstr="$prog [Depends]"
case $prog in
/* ) ;;
* ) prog=$here/$prog ;;
esac

cleanup()
{
	if test X$PRESERVE = X -a X$1 = X ; then
		cd $here
		find $work -type d -user $USER -exec chmod u+w {} \;
		rm -rf $work
	else
		echo Preserving work directory $work
	fi
}

no_result()
{
	set +x
	echo NO RESULT for test of $progstr 1>&2
	cleanup $PRESERVE_NO_RESULT
	exit 2
}
fail()
{
	set +x
	if test "$1" ; then teststr=" #$1" ; fi
	if test "$2" ; then
		echo FAILED test$teststr of $progstr, input: 1>&2
		cat $2 1>&2
	fi
	echo FAILED test of $progstr 1>&2
	cleanup $PRESERVE_FAIL
	exit 1
}
pass()
{
	set +x
	echo PASSED 1>&2
	cleanup $PRESERVE_PASS
	exit 0
}
trap "no_result" 1 2 3 15

#
# make the work directory
#
mkdir $work
if test $? -ne 0 ; then exit 2 ; fi
cd $work
if test $? -ne 0 ; then exit 2 ; fi

#
cat <<'_EOF_' >Construct
$env = new cons;
Program $env 'foo', 'foo.c';
Ignore '^foo.h';
Depends $env 'foo.o', 'foo.dep';
_EOF_
if test $? -ne 0 ; then no_result ; fi
cat <<'_EOF_' >foo.c
#include "foo.h"
main()
{
	printf("%s\n", STRING);
	exit (0);
}
_EOF_
if test $? -ne 0 ; then no_result ; fi
cat <<'_EOF_' >foo.dep
xyzzy
_EOF_
if test $? -ne 0 ; then no_result ; fi

cat <<'_EOF_' >foo.h
#define	STRING	"SUCCESS!"
_EOF_
if test $? -ne 0 ; then no_result ; fi

$prog . > cons.1.out 2>&1
if test $? -ne 0 ; then fail ; fi
./foo > foo.out
if test $? -ne 0 ; then fail ; fi
diff - foo.out <<'_EOF_'
SUCCESS!
_EOF_
if test $? -ne 0 ; then fail ; fi

cat <<'_EOF_' >foo.h
#define	STRING	"SUCCESS AGAIN!"
_EOF_
if test $? -ne 0 ; then no_result ; fi

$prog . > cons.2.out 2>&1
if test $? -ne 0 ; then fail ; fi
./foo > foo.out
if test $? -ne 0 ; then fail ; fi
diff - foo.out <<'_EOF_'
SUCCESS!
_EOF_
if test $? -ne 0 ; then fail ; fi

cat <<'_EOF_' >foo.dep
abracadabra
_EOF_
if test $? -ne 0 ; then no_result ; fi

$prog . > cons.3.out 2>&1
if test $? -ne 0 ; then fail ; fi
./foo > foo.out
if test $? -ne 0 ; then fail ; fi
diff - foo.out <<'_EOF_'
SUCCESS AGAIN!
_EOF_
if test $? -ne 0 ; then fail ; fi

#
pass
